@@ -245,14 +245,14 @@ func itoNot(p *Process, params []string, object *interface{}, marshaller func(in
 			}
 		}
 
-		if len(objArray) > 0 {
-			b, err := marshaller(objArray)
-			if err != nil {
-				return err
-			}
-			p.Stdout.Writeln(b)
+		//if len(objArray) > 0 {
+		b, err := marshaller(objArray)
+		if err != nil {
+			return err
 		}
-		return nil
+		_, err = p.Stdout.Writeln(b)
+		//}
+		return err
 
 	case map[string]interface{}:
 		objMap := make(map[string]interface{})
@@ -271,13 +271,13 @@ func itoNot(p *Process, params []string, object *interface{}, marshaller func(in
 			}
 		}
 
-		if len(objMap) > 0 {
-			b, err := marshaller(objMap)
-			if err != nil {
-				return err
-			}
-			p.Stdout.Writeln(b)
+		//if len(objMap) > 0 {
+		b, err := marshaller(objMap)
+		if err != nil {
+			return err
 		}
+		p.Stdout.Writeln(b)
+		//}
 		return nil
 
 	case map[interface{}]interface{}:
@@ -298,14 +298,14 @@ func itoNot(p *Process, params []string, object *interface{}, marshaller func(in
 			}
 		}
 
-		if len(objMap) > 0 {
-			b, err := marshaller(objMap)
-			if err != nil {
-				return err
-			}
-			p.Stdout.Writeln(b)
+		//if len(objMap) > 0 {
+		b, err := marshaller(objMap)
+		if err != nil {
+			return err
 		}
-		return nil
+		_, err = p.Stdout.Writeln(b)
+		//}
+		return err
 
 	default:
 		return errors.New("object cannot be !indexed")
