@@ -1,18 +1,28 @@
+//go:build windows
 // +build windows
 
 package man
 
+import (
+	"github.com/lmorg/murex/lang/stdio"
+)
+
 // ScanManPages - windows doesn't have man pages so lets just create an empty
 // function that returns a zero-lengthed array so murex can compile on Windows
 // but without support for flag auto-detection.
-func GetManPages(exe string) []string { return []string{} }
+func GetManPages(_ string) []string { return []string{} }
 
-// ParseFlags - windows doesn't have man pages so lets just create an empty
+// ParseByPaths - windows doesn't have man pages so lets just create an empty
 // function that returns a zero-lengthed array so murex can compile on Windows
 // but without support for flag auto-detection.
-func ParseFlags(paths []string) (flags []string) { return []string{} }
+func ParseByPaths(_ []string) []string { return []string{} }
+
+// ParseByStdio - windows doesn't have man pages so lets just create an empty
+// function that returns a zero-lengthed array so murex can compile on Windows
+// but without support for flag auto-detection.
+func ParseByStdio(_ stdio.Io) []string { return []string{} }
 
 // ParseDescription - windows doesn't have man pages so lets just create an empty
 // function that returns a zero-lengthed string so murex can compile on Windows
 // but without support for flag auto-detection.
-func ParseSummary(paths []string) string { return "" }
+func ParseSummary(_ []string) string { return "" }
